@@ -61,7 +61,7 @@ types_dic = {
     },
     '13': {
         'character': ["Reimu", "Marisa", "Sanae", "Youmu"],
-        'ctype': [""],
+        'ctype': [],
         'rank': ["Easy", "Normal", "Hard", "Lunatic", "Extra", "overdrive"],
         'clear': [f"Stage {i}" for i in range(7)] + ["Extra", "All"]
     },
@@ -73,7 +73,7 @@ types_dic = {
     },
     '15': {
         'character': ["Reimu", "Marisa", "Sanae", "Reisen"],
-        'ctype': [""],
+        'ctype': [],
         'rank': ["Easy", "Normal", "Hard", "Lunatic", "Extra"],
         'clear': [f"Stage {i}" for i in range(7)] + ["Extra", "All"]
     },
@@ -85,7 +85,7 @@ types_dic = {
     },
     '128': {
         'character': ["A1", "A2", "B1", "B2", "C1", "C2", "Extra"],
-        'ctype': [""],
+        'ctype': [],
         'rank': ["Easy", "Normal", "Hard", "Lunatic", "Extra"],
         'clear': ['dummy', 'A1-1','A1-2','A1-3','A2-2','A2-3','B1-1','B1-2','B1-3','B2-2','B2-3','C1-1','C1-2','C1-3','C2-2','C2-3','Extra','All','All','All','All','All','All','All']
     },
@@ -93,25 +93,25 @@ types_dic = {
         'character': ["Aya", "Hatate"],
         'ctype': [f"{i+1}" for i in range(12)] + ["EX", "SP"],
         'rank': [f"{i+1}" for i in range(9)],
-        'clear': [""]
+        'clear': []
     },
     '143': {
-        'character': [""],
+        'character': [],
         'ctype': [f"{i+1}" for i in range(10)],
         'rank': [f"{i+1}" for i in range(10)],
-        'clear': [""]
+        'clear': []
     },
     '95': {
-        'character': [""],
+        'character': [],
         'ctype': [f"{i+1}" for i in range(10)] + ["EX"],
         'rank': [f"{i+1}" for i in range(8)],
-        'clear': [""]
+        'clear': []
     },
     '165': {
         'character': ["Usami"],
         'ctype': [f"{i+1}" for i in range(6)],
         'rank': [week_array[i % 7] for i in range(7)] + [f"Inner-{week_array[i % 7]}" for i in range(7, 14)] + [f"Nightmare-{week_array[i % 7]}" for i in range(14, 21)],
-        'clear': [""]
+        'clear': []
     },
     '17': {
         'character': ["Reimu", "Marisa", "Youmu"],
@@ -121,7 +121,7 @@ types_dic = {
     },
     '18': {
         'character': ["Reimu", "Marisa", "Sakuya", "Sanae"],
-        'ctype': [""],
+        'ctype': [],
         'rank': ["Easy", "Normal", "Hard", "Lunatic", "Extra"],
         'clear': [f"Stage {i}" for i in range(7)] + ["Extra", "All"]
     }
